@@ -8,7 +8,6 @@ __author__ = "Michael Shobitan"
 __copyright__ = "Copyright 2019, BTCS Platform Engineering"
 __credits__ = ["Michael Shobitan"]
 __license__ = "PFE"
-__version__ = "0.2.2"
 __maintainer__ = "Michael Shobitan"
 __email__ = "michael.shobitan@pfizer.com"
 __status__ = "Development"
@@ -183,13 +182,14 @@ def describe_stack(cloudformation, cluster):
     return response
 
 def describe_stack_dynamically(cloudformation, cluster):
+    print(0)
     response = cloudformation.describe_stacks()
     responseMore = cloudformation.describe_stacks(NextToken=response['NextToken'])
     allResponses = [response, responseMore]
 
     clusterStackNames = []
     stacksINFO = []
-    def aggregateAllStackInfo(thisResponse):
+    def aggregateAllStackInfo(response):
         if(sys.version_info > (3, 0)):
             for counter in range(len(response['Stacks'])): # Python3.6
                 stackName = response['Stacks'][counter]['StackName']
@@ -209,13 +209,69 @@ def describe_stack_dynamically(cloudformation, cluster):
 
         return clusterStackNames, stacksINFO
 
+    print(1)
     for thisResponse in allResponses:
         allStackData = aggregateAllStackInfo(thisResponse)
     
     clusterStackNames.append(allStackData[0])
     stacksINFO.append(allStackData[1])
+    
+    if(len(clusterStackNames > 0)):
+        return {'clusterStackNames': clusterStackNames, 'stacksINFO': stacksINFO}
+    
+    response = cloudformation.describe_stacks()
+    responseMore = cloudformation.describe_stacks(NextToken=response['NextToken'])
+    allResponses = [response, responseMore]
 
-    return {'clusterStackNames': clusterStackNames, 'stacksINFO': stacksINFO}
+    clusterStackNames = []
+    stacksINFO = []
+    def aggregateAllStackInfo(response):
+        clusterStackNames = []
+        stacksINFO = []
+        if(sys.version_info > (3, 0)):
+            for counter in range(len(response['Stacks'])): # Python3.6
+                stackName = response['Stacks'][counter]['StackName']
+                if(cluster in stackName):
+                    clusterStackNames.append(stackName)
+                    # print(response['Stacks'][counter])
+                    stacksINFO.append(response['Stacks'][counter])
+                    # print(json.dumps(response['Stacks'][counter], indent=4, sort_keys=True, default=str))
+        else:
+            for counter in xrange(len(response['Stacks'])): # Python2.7
+                stackName = response['Stacks'][counter]['StackName']
+                if(cluster in stackName):
+                    clusterStackNames.append(stackName)
+                    # print(response['Stacks'][counter])
+                    stacksINFO.append(response['Stacks'][counter])
+                    # print(json.dumps(response['Stacks'][counter], indent=4, sort_keys=True, default=str))
+
+        # print(clusterStackNames)
+        return clusterStackNames, stacksINFO
+
+    print(2)
+    for thisResponse in allResponses:
+        allStackData = aggregateAllStackInfo(thisResponse)
+        # print(allStackData)
+        clusterStackNames.append(allStackData[0])
+        stacksINFO.append(allStackData[1])
+
+    clusterStackNames = [x for x in clusterStackNames if x != []]
+    clusterStackNamesCleaned = []
+    for stack in clusterStackNames:
+        stack = stack[0]
+        print(stack)
+        clusterStackNamesCleaned.append(stack)
+    print(clusterStackNamesCleaned)
+
+    stacksINFO = [x for x in stacksINFO if x != []]
+    stacksINFOCleaned = []
+    for stack in stacksINFO:
+        stack = stack[0]
+        # print(stack)
+        stacksINFOCleaned.append(stack)
+    # print(stacksINFOCleaned)
+    
+    return {'clusterStackNames': clusterStackNamesCleaned, 'stacksINFO': stacksINFOCleaned}
 
 def cahc(cluster):
     eks = eks()
